"""
Configs migration

Generation datetime: 2021-01-25 07:25:55.779253
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "8bd6e404"
DOWN_REVISION = "bc48d6fc"


def upgradeAdditionalServiceUsagesSetting(setting: dict) -> dict:
    """Upgrade AdditionalServiceUsages setting."""
    setting["matcher"] = True
    return setting


def downgradeAdditionalServiceUsagesSetting(setting: dict) -> dict:
    """Downgrade AdditionalServiceUsages setting."""
    setting.pop("matcher", None)
    return setting


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "indexed_matcher": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "liveness": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "indexed_matcher",
                "luna_matcher_proxy",
                "liveness",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "matcher": {"type": "boolean"},
                "indexed_matcher": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "liveness": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "matcher",
                "indexed_matcher",
                "luna_matcher_proxy",
                "liveness",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "indexed_matcher": False,
            "luna_matcher_proxy": False,
            "liveness": False,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "matcher": True,
            "indexed_matcher": False,
            "luna_matcher_proxy": False,
            "liveness": False,
        },
        settingUpgradeFunction=upgradeAdditionalServiceUsagesSetting,
        settingDowngradeFunction=downgradeAdditionalServiceUsagesSetting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
