"""
Configs migration

Generation datetime: 2021-05-28 13:18:56.376157
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "f4c31695"
DOWN_REVISION = "5da4c2f3"

OLD_DHDV = 101
NEW_DHDV = 104
OLD_DFDV = 56
NEW_DFDV = 59

limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="DEFAULT_HUMAN_DESCRIPTOR_VERSION",
        oldDefaultValue=OLD_DHDV,
        newDefaultValue=NEW_DHDV,
        settingUpgradeFunction=lambda oldValue: NEW_DHDV if oldValue == OLD_DHDV else oldValue,
        settingDowngradeFunction=lambda oldValue: OLD_DHDV if oldValue == NEW_DHDV else oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
        newServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
    ),
    LimitationToModify(
        limitationName="DEFAULT_FACE_DESCRIPTOR_VERSION",
        oldDefaultValue=OLD_DFDV,
        newDefaultValue=NEW_DFDV,
        settingUpgradeFunction=lambda oldValue: oldValue,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
        newServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
