"""

Configs migration



Generation datetime: 2022-11-30 12:37:03.015537

"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "b7990268"

DOWN_REVISION = "ff3392de"


def settingUpgradeFunction(setting: dict):
    setting.get("estimator_settings", {}).pop("max_face_size", None)
    return setting


def settingDowngradeFunction(setting: dict):
    setting.get("estimator_settings", {})["max_face_size"] = 640
    return setting


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_HANDLERS_FACE_DETECTOR_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "min_face_size": {"type": "integer", "minimum": 1},
                        "max_face_size": {"type": "integer", "minimum": 1},
                        "redetect_tensor_size": {"type": "integer", "minimum": 1},
                        "redetect_face_target_size": {"type": "integer", "minimum": 1},
                        "redetect_score_threshold": {"type": "number"},
                        "score_threshold": {"type": "number"},
                    },
                    "description": "settings for face detector version 3",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk face detector",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "min_face_size": {"type": "integer", "minimum": 1},
                        "redetect_tensor_size": {"type": "integer", "minimum": 1},
                        "redetect_face_target_size": {"type": "integer", "minimum": 1},
                        "redetect_score_threshold": {"type": "number"},
                        "score_threshold": {"type": "number"},
                    },
                    "description": "settings for face detector version 3",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk face detector",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "max_face_size": 640,
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 45,
                "redetect_score_threshold": 0.3,
                "score_threshold": 0.42,
            },
        },
        newDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 45,
                "redetect_score_threshold": 0.3,
                "score_threshold": 0.42,
            },
        },
        oldDescription="luna-handlers settings for face detector",
        newDescription="luna-handlers settings for face detector",
        oldGroupNames=["luna-platform", "luna-handlers-estimators-settings"],
        newGroupNames=["luna-platform", "luna-handlers-estimators-settings"],
        settingUpgradeFunction=settingUpgradeFunction,
        settingDowngradeFunction=settingDowngradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
