"""
Configs migration

Generation datetime: 2023-07-17 11:55:15.403501
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "f9c5c1fb"
DOWN_REVISION = "c0e7b9e0"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="DEFAULT_HUMAN_DESCRIPTOR_VERSION",
        oldDefaultValue=107,
        newDefaultValue=110,
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
        newServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
