"""
Configs migration

Generation datetime: 2023-11-01 14:54:51.445400
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "9c6b9bbd"
DOWN_REVISION = "5742d47f"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="CLUSTER_LOCATION",
        oldValidationSchema={"type": "string", "enum": ["remote", "local", "internal"]},
        newValidationSchema={"type": "string", "enum": ["remote", "local", "internal"]},
        oldDefaultValue="remote",
        newDefaultValue="internal",
        oldDescription="k8s cluster location: remote/local(executed on same machine)/internal(executed in cluster)",
        newDescription="k8s cluster location: remote/local(executed on same machine)/internal(executed in cluster)",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-lambda"],
        newServices=["luna-lambda"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
