"""
Configs migration

Generation datetime: 2023-12-19 17:21:49.985093
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "00cf21b7"
DOWN_REVISION = "5ad592b2"


limitationsToModify: list[LimitationToModify] = []

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        defaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "storage": "./videos",
            "max_size": 1024,
        },
        description="luna-remote-sdk video processing settings",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS")
