"""
Configs migration

Generation datetime: 2024-11-18 14:56:59.338248
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "77c6d183"
DOWN_REVISION = "9514a783"


def upgrade(setting):
    if setting is not None:
        setting["face_occlusion"] = {"threshold": 0}
        setting["lower_face_occlusion"] = {"threshold": 0}
        setting["forehead_occlusion"] = {"threshold": 0}
        setting["nose_occlusion"] = {"threshold": 0}
    return setting


def downgrade(setting):
    if setting is not None:
        setting.pop("face_occlusion", None)
        setting.pop("lower_face_occlusion", None)
        setting.pop("forehead_occlusion", None)
        setting.pop("nose_occlusion", None)
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="FACE_QUALITY_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "image_format": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["JPEG", "JPEG2000", "PNG"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "illumination": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "specularity": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "blurriness": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "dark": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "light": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_yaw": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_pitch": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_roll": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "gaze_yaw": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "gaze_pitch": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "mouth_smiling": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "mouth_occluded": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "mouth_open": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "glasses": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["no_glasses", "eyeglasses", "sunglasses"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "eyes": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["open", "occluded", "closed"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "head_horizontal_center": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_vertical_center": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_width": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_height": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "eye_distance": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0},
                                "max": {"type": "number", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "image_width": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "image_height": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "aspect_ratio": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0},
                                "max": {"type": "number", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "face_width": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "face_height": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_left": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_right": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_upper": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_lower": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "image_size": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "illumination_uniformity": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "dynamic_range": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "eyebrows": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["neutral", "raised", "squinting", "frowning"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "shoulders": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["non-parallel", "parallel", "hidden"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "smile": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["none", "smile_lips", "smile_teeth"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "headwear": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": [
                                    "none",
                                    "baseball_cap",
                                    "beanie",
                                    "peaked_cap",
                                    "shawl",
                                    "hat_with_earflaps",
                                    "helmet",
                                    "hood",
                                    "hat",
                                    "other",
                                ],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "natural_light": {
                    "type": "object",
                    "properties": {
                        "threshold": {"type": "integer", "enum": [0, 1]},
                        "config": {
                            "type": "object",
                            "properties": {
                                "estimator": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                }
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "fish_eye": {
                    "type": "object",
                    "properties": {
                        "threshold": {"type": "integer", "enum": [0, 1]},
                        "config": {
                            "type": "object",
                            "properties": {
                                "estimator": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                }
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "red_eye": {
                    "type": "object",
                    "properties": {
                        "threshold": {"type": "integer", "enum": [0, 1]},
                        "config": {
                            "type": "object",
                            "properties": {
                                "estimator": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                }
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "color_type": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["color", "grayscale", "infrared"],
                            },
                        },
                        "config": {
                            "type": "object",
                            "properties": {
                                "infrared": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                },
                                "color": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                },
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "background_lightness": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "background_uniformity": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
            },
            "description": "settings for face quality checks",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "image_format": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["JPEG", "JPEG2000", "PNG"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "illumination": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "specularity": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "blurriness": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "dark": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "light": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_yaw": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_pitch": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_roll": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "gaze_yaw": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "gaze_pitch": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                                "max": {
                                    "type": "number",
                                    "minimum": -180,
                                    "maximum": 180,
                                },
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "mouth_smiling": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "mouth_occluded": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "mouth_open": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "glasses": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["no_glasses", "eyeglasses", "sunglasses"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "eyes": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["open", "occluded", "closed"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "head_horizontal_center": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_vertical_center": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_width": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "head_height": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "eye_distance": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0},
                                "max": {"type": "number", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "image_width": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "image_height": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "aspect_ratio": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0},
                                "max": {"type": "number", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "face_width": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "face_height": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_left": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_right": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_upper": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "indent_lower": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "image_size": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "integer", "minimum": 0},
                                "max": {"type": "integer", "minimum": 0},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "illumination_uniformity": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "dynamic_range": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "eyebrows": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["neutral", "raised", "squinting", "frowning"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "shoulders": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["non-parallel", "parallel", "hidden"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "smile": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["none", "smile_lips", "smile_teeth"],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "headwear": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": [
                                    "none",
                                    "baseball_cap",
                                    "beanie",
                                    "peaked_cap",
                                    "shawl",
                                    "hat_with_earflaps",
                                    "helmet",
                                    "hood",
                                    "hat",
                                    "other",
                                ],
                            },
                        }
                    },
                    "additionalProperties": False,
                },
                "natural_light": {
                    "type": "object",
                    "properties": {
                        "threshold": {"type": "integer", "enum": [0, 1]},
                        "config": {
                            "type": "object",
                            "properties": {
                                "estimator": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                }
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "fish_eye": {
                    "type": "object",
                    "properties": {
                        "threshold": {"type": "integer", "enum": [0, 1]},
                        "config": {
                            "type": "object",
                            "properties": {
                                "estimator": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                }
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "red_eye": {
                    "type": "object",
                    "properties": {
                        "threshold": {"type": "integer", "enum": [0, 1]},
                        "config": {
                            "type": "object",
                            "properties": {
                                "estimator": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                }
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "color_type": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "array",
                            "items": {
                                "type": "string",
                                "enum": ["color", "grayscale", "infrared"],
                            },
                        },
                        "config": {
                            "type": "object",
                            "properties": {
                                "infrared": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                },
                                "color": {
                                    "type": "object",
                                    "properties": {
                                        "threshold": {
                                            "type": "object",
                                            "properties": {
                                                "min": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                                "max": {
                                                    "type": "number",
                                                    "minimum": 0,
                                                    "maximum": 1,
                                                },
                                            },
                                            "additionalProperties": False,
                                        }
                                    },
                                    "additionalProperties": False,
                                },
                            },
                            "additionalProperties": False,
                        },
                    },
                    "additionalProperties": False,
                },
                "background_lightness": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "background_uniformity": {
                    "type": "object",
                    "properties": {
                        "threshold": {
                            "type": "object",
                            "properties": {
                                "min": {"type": "number", "minimum": 0, "maximum": 1},
                                "max": {"type": "number", "minimum": 0, "maximum": 1},
                            },
                            "additionalProperties": False,
                        }
                    },
                    "additionalProperties": False,
                },
                "face_occlusion": {
                    "type": "object",
                    "properties": {"threshold": {"type": "integer", "enum": [0, 1]}},
                    "additionalProperties": False,
                },
                "lower_face_occlusion": {
                    "type": "object",
                    "properties": {"threshold": {"type": "integer", "enum": [0, 1]}},
                    "additionalProperties": False,
                },
                "forehead_occlusion": {
                    "type": "object",
                    "properties": {"threshold": {"type": "integer", "enum": [0, 1]}},
                    "additionalProperties": False,
                },
                "nose_occlusion": {
                    "type": "object",
                    "properties": {"threshold": {"type": "integer", "enum": [0, 1]}},
                    "additionalProperties": False,
                },
            },
            "description": "settings for face quality checks",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "image_format": {"threshold": ["JPEG", "JPEG2000", "PNG"]},
            "illumination": {"threshold": {"min": 0.3, "max": 1}},
            "specularity": {"threshold": {"min": 0.3, "max": 1}},
            "blurriness": {"threshold": {"min": 0.61, "max": 1}},
            "dark": {"threshold": {"min": 0.5, "max": 1}},
            "light": {"threshold": {"min": 0.57, "max": 1}},
            "head_yaw": {"threshold": {"min": -5, "max": 5}},
            "head_pitch": {"threshold": {"min": -5, "max": 5}},
            "head_roll": {"threshold": {"min": -8, "max": 8}},
            "gaze_yaw": {"threshold": {"min": -5, "max": 5}},
            "gaze_pitch": {"threshold": {"min": -5, "max": 5}},
            "mouth_smiling": {"threshold": {"min": 0, "max": 0.5}},
            "mouth_occluded": {"threshold": {"min": 0, "max": 0.5}},
            "mouth_open": {"threshold": {"min": 0, "max": 0.5}},
            "glasses": {"threshold": ["no_glasses", "eyeglasses"]},
            "eyes": {"threshold": ["open"]},
            "head_horizontal_center": {"threshold": {"min": 0.45, "max": 0.55}},
            "head_vertical_center": {"threshold": {"min": 0.3, "max": 0.5}},
            "head_width": {"threshold": {"min": 0.5, "max": 0.75}},
            "head_height": {"threshold": {"min": 0.6, "max": 0.9}},
            "eye_distance": {"threshold": {"min": 90}},
            "image_width": {"threshold": {"min": 180, "max": 1920}},
            "image_height": {"threshold": {"min": 180, "max": 1080}},
            "aspect_ratio": {"threshold": {"min": 0.74, "max": 0.8}},
            "face_width": {"threshold": {"min": 180}},
            "face_height": {"threshold": {"min": 180}},
            "indent_left": {"threshold": {"min": 20}},
            "indent_right": {"threshold": {"min": 20}},
            "indent_upper": {"threshold": {"min": 20}},
            "indent_lower": {"threshold": {"min": 20}},
            "image_size": {"threshold": {"min": 5120, "max": 2097152}},
            "illumination_uniformity": {"threshold": {"min": 0.5}},
            "dynamic_range": {"threshold": {"min": 0.5}},
            "eyebrows": {"threshold": ["neutral"]},
            "shoulders": {"threshold": ["parallel"]},
            "smile": {"threshold": ["none"]},
            "headwear": {"threshold": ["none"]},
            "natural_light": {
                "threshold": 1,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "fish_eye": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "red_eye": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "color_type": {
                "threshold": ["color"],
                "config": {
                    "infrared": {"threshold": {"min": 0.5}},
                    "color": {"threshold": {"min": 0.5}},
                },
            },
            "background_lightness": {"threshold": {"min": 0.2}},
            "background_uniformity": {"threshold": {"min": 0.5}},
        },
        newDefaultValue={
            "image_format": {"threshold": ["JPEG", "JPEG2000", "PNG"]},
            "illumination": {"threshold": {"min": 0.3, "max": 1}},
            "specularity": {"threshold": {"min": 0.3, "max": 1}},
            "blurriness": {"threshold": {"min": 0.61, "max": 1}},
            "dark": {"threshold": {"min": 0.5, "max": 1}},
            "light": {"threshold": {"min": 0.57, "max": 1}},
            "head_yaw": {"threshold": {"min": -5, "max": 5}},
            "head_pitch": {"threshold": {"min": -5, "max": 5}},
            "head_roll": {"threshold": {"min": -8, "max": 8}},
            "gaze_yaw": {"threshold": {"min": -5, "max": 5}},
            "gaze_pitch": {"threshold": {"min": -5, "max": 5}},
            "mouth_smiling": {"threshold": {"min": 0, "max": 0.5}},
            "mouth_occluded": {"threshold": {"min": 0, "max": 0.5}},
            "mouth_open": {"threshold": {"min": 0, "max": 0.5}},
            "glasses": {"threshold": ["no_glasses", "eyeglasses"]},
            "eyes": {"threshold": ["open"]},
            "head_horizontal_center": {"threshold": {"min": 0.45, "max": 0.55}},
            "head_vertical_center": {"threshold": {"min": 0.3, "max": 0.5}},
            "head_width": {"threshold": {"min": 0.5, "max": 0.75}},
            "head_height": {"threshold": {"min": 0.6, "max": 0.9}},
            "eye_distance": {"threshold": {"min": 90}},
            "image_width": {"threshold": {"min": 180, "max": 1920}},
            "image_height": {"threshold": {"min": 180, "max": 1080}},
            "aspect_ratio": {"threshold": {"min": 0.74, "max": 0.8}},
            "face_width": {"threshold": {"min": 180}},
            "face_height": {"threshold": {"min": 180}},
            "indent_left": {"threshold": {"min": 20}},
            "indent_right": {"threshold": {"min": 20}},
            "indent_upper": {"threshold": {"min": 20}},
            "indent_lower": {"threshold": {"min": 20}},
            "image_size": {"threshold": {"min": 5120, "max": 2097152}},
            "illumination_uniformity": {"threshold": {"min": 0.5}},
            "dynamic_range": {"threshold": {"min": 0.5}},
            "eyebrows": {"threshold": ["neutral"]},
            "shoulders": {"threshold": ["parallel"]},
            "smile": {"threshold": ["none"]},
            "headwear": {"threshold": ["none"]},
            "natural_light": {
                "threshold": 1,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "fish_eye": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "red_eye": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "color_type": {
                "threshold": ["color"],
                "config": {
                    "infrared": {"threshold": {"min": 0.5}},
                    "color": {"threshold": {"min": 0.5}},
                },
            },
            "background_lightness": {"threshold": {"min": 0.2}},
            "background_uniformity": {"threshold": {"min": 0.5}},
            "face_occlusion": {"threshold": 0},
            "lower_face_occlusion": {"threshold": 0},
            "forehead_occlusion": {"threshold": 0},
            "nose_occlusion": {"threshold": 0},
        },
        settingUpgradeFunction=upgrade,
        settingDowngradeFunction=downgrade,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-remote-sdk"],
        newServices=["luna-remote-sdk"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
