"""
Module contains tests for current dumps
"""

import decimal
import json
import os
import unittest
from pathlib import Path

from configs_core.migration.consts import ACTUAL_DUMP_FILENAME
from configs_core.migration.migrate import MigrationProcessor

from configs.dump.services import LUNA_PLATFORM

MIGRATION_ABS_PATH = Path(__file__).parent.parent / "configs" / "migration"
DB_URL = "postgres://luna:luna@127.0.0.1:5432/luna_configurator"


class TestRevisions(unittest.TestCase):
    """Test revisions existence"""

    def test_no_duplicated_revisions(self):
        """Test no duplicated revisions exists"""
        existingRevisions = MigrationProcessor(
            DB_URL, migration=MIGRATION_ABS_PATH, services=LUNA_PLATFORM, component="platform"
        ).getExistingRevisions()
        self.assertEqual(len(set(existingRevisions.values())), len(existingRevisions), msg="Duplicated head detected!")

    def test_no_forgotten_revisions(self):
        """Test no forgotten revisions in revisions path"""
        usefulRevisions = list(
            filter(
                lambda x: x.endswith(".py") and not x == "base_revision.py", os.listdir(MIGRATION_ABS_PATH / "versions")
            )
        )
        existingRevisions = MigrationProcessor(
            DB_URL, migration=MIGRATION_ABS_PATH, services=LUNA_PLATFORM, component="platform"
        ).getExistingRevisions()
        self.assertEqual(len(usefulRevisions), len(existingRevisions), msg="Existing revisions count does not match")

    def test_head(self):
        """Test json dump file head match revisions head"""
        mp = MigrationProcessor(DB_URL, migration=MIGRATION_ABS_PATH, services=LUNA_PLATFORM, component="platform")
        filesHeadRevision = mp.getSortedRevisions(mp.getExistingRevisions())[-1]
        with open(Path(Path(__file__).parent.parent / "configs" / "migration" / ACTUAL_DUMP_FILENAME), "r") as dumpFile:
            jsonHeadRevision = json.loads(dumpFile.read(), parse_float=decimal.Decimal())["version"]
        self.assertEqual(
            filesHeadRevision,
            jsonHeadRevision,
            msg="Head revision from json dump does not match head revision from files",
        )
