from time import time

from cow.monitoring.points import BaseMonitoringPoint


class MonitoringPoint(BaseMonitoringPoint):
    """User monitoring point"""

    #: series
    series: str
    #: service name
    service: str

    __slots__ = ("pointTags", "pointFields")

    def __init__(self, pointTags: dict, pointFields: dict):
        super().__init__(time())
        self.pointTags = pointTags
        self.pointFields = pointFields

    @classmethod
    def initialize(cls, serviceName: str):
        """
        Initialize request point for custom service.
        Args:
            serviceName: service name
        """
        cls.service = serviceName

    @property
    def tags(self) -> dict:
        """
        Get point tags

        Returns:
            dict with service as keys + additionalTags
        """
        return {"service": self.service, **self.pointTags}

    @property
    def fields(self) -> dict:
        """
        Get point fields

        Returns:
            dict with additional fields
        """
        return self.pointFields
